@@ -23,14 +23,14 @@ function run_as_ferry {
 source /etc/profile
 if [ $1 == "python" ]; then
     if [ $# == 2 ]; then
-	run_as_ferry "$SPARK_HOME/bin/pyspark /service/examples/python/$2 spark://$BACKEND_COMPUTE_MASTER:7077" "Running $2"
+	run_as_ferry "$SPARK_HOME/bin/spark-submit /service/examples/python/$2 spark://$BACKEND_COMPUTE_MASTER:7077" "Running $2"
     fi
 elif [ $1 == "load" ]; then
     MKDIR='hdfs dfs -mkdir -p /spark/data'
-    COPY1='hdfs dfs -copyFromLocal $SPARK_HOME/mllib/data/als/test.data /spark/data/als.data'
-    COPY2='hdfs dfs -copyFromLocal $SPARK_HOME/mllib/data/sample_svm_data.txt /spark/data/svm.txt'
-    COPY3='hdfs dfs -copyFromLocal $SPARK_HOME/mllib/data/ridge-data/lpsa.data /spark/data/lpsa.data'
-    COPY4='hdfs dfs -copyFromLocal $SPARK_HOME/data/kmeans_data.txt /spark/data/kmeans.txt'
+    COPY1='hdfs dfs -copyFromLocal /service/examples/data/als_test.data /spark/data/als.data'
+    COPY2='hdfs dfs -copyFromLocal /service/examples/data/svm_test.data /spark/data/svm.data'
+    COPY3='hdfs dfs -copyFromLocal /service/examples/data/lpsa_test.data /spark/data/lpsa.data'
+    COPY4='hdfs dfs -copyFromLocal /service/examples/data/kmeans_test.data /spark/data/kmeans.data'
 
     run_as_ferry "$MKDIR" "Making Spark data directories"
     run_as_ferry "$COPY1" "Upload dataset 1"
@@ -38,5 +38,5 @@ elif [ $1 == "load" ]; then
     run_as_ferry "$COPY3" "Upload dataset 3"
     run_as_ferry "$COPY4" "Upload dataset 4"
 elif [ $1 == "example" ]; then
-    run_as_ferry '$SPARK_HOME/bin/run-example org.apache.spark.examples.SparkPi spark://$BACKEND_COMPUTE_MASTER:7077'
+    run_as_ferry '$SPARK_HOME/bin/spark-submit --class org.apache.spark.examples.SparkPi --master spark://$BACKEND_COMPUTE_MASTER:7077 $SPARK_HOME/lib/spark-examples-1.1.0-hadoop2.4.0.jar'
 fi
